Type: Package
Package: rfm
Title: Recency, Frequency and Monetary Value Analysis
Version: 0.4.0
Authors@R: person("Aravind", "Hebbali", email = "hebbali.aravind@gmail.com", role = c("aut", "cre"),
    comment = c(ORCID = "0000-0001-9220-9669"))
Description: Tools for RFM (recency, frequency and monetary value) analysis. 
    Generate RFM score from both transaction and customer level data. Visualize the
    relationship between recency, frequency and monetary value using heatmap, 
    histograms, bar charts and scatter plots. Includes a 'shiny' app for 
    interactive segmentation. References:
    i. Blattberg R.C., Kim BD., Neslin S.A (2008) <doi:10.1007/978-0-387-72579-6_12>.
License: MIT + file LICENSE
URL: https://github.com/rsquaredacademy/rfm,
        https://rfm.rsquaredacademy.com/
BugReports: https://github.com/rsquaredacademy/rfm/issues
Depends: R (>= 3.2)
Imports: dplyr, gganimate, ggplot2, magrittr, plotly, RColorBrewer,
        rlang, scales, stats, treemapify, utils, xplorerr
Suggests: cli, covr, DT, kableExtra, knitr, rmarkdown, rmdformats,
        testthat (>= 3.0.0), vdiffr
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-30 07:56:04 UTC; HP
Author: Aravind Hebbali [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9220-9669>)
Maintainer: Aravind Hebbali <hebbali.aravind@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-30 09:00:02 UTC
Built: R 4.6.0; ; 2026-05-01 22:15:42 UTC; unix
