# Generated by roxygen2: do not edit by hand

S3method(print,rfm_table_customer)
S3method(print,rfm_table_order)
S3method(rfm_table_customer,default)
S3method(rfm_table_order,default)
export(rfm_bar_chart)
export(rfm_barchart_data)
export(rfm_create_report)
export(rfm_fm_plot)
export(rfm_heatmap)
export(rfm_heatmap_data)
export(rfm_histograms)
export(rfm_launch_app)
export(rfm_order_dist)
export(rfm_plot_bar_chart)
export(rfm_plot_heatmap)
export(rfm_plot_histogram)
export(rfm_plot_median_frequency)
export(rfm_plot_median_monetary)
export(rfm_plot_median_recency)
export(rfm_plot_order_dist)
export(rfm_plot_revenue_dist)
export(rfm_plot_segment)
export(rfm_plot_segment_scatter)
export(rfm_plot_segment_summary)
export(rfm_rf_plot)
export(rfm_rm_plot)
export(rfm_segment)
export(rfm_segment_summary)
export(rfm_table_customer)
export(rfm_table_customer_2)
export(rfm_table_order)
importFrom(RColorBrewer,brewer.pal)
importFrom(dplyr,arrange)
importFrom(dplyr,between)
importFrom(dplyr,distinct)
importFrom(dplyr,everything)
importFrom(dplyr,group_by)
importFrom(dplyr,join_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,position_dodge)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,sec_axis)
importFrom(ggplot2,theme)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(magrittr,"%<>%")
importFrom(magrittr,"%>%")
importFrom(magrittr,add)
importFrom(magrittr,extract)
importFrom(magrittr,multiply_by)
importFrom(magrittr,set_names)
importFrom(magrittr,use_series)
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,int)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,reorder)
importFrom(stats,runif)
importFrom(treemapify,geom_treemap)
importFrom(treemapify,geom_treemap_text)
importFrom(utils,available.packages)
importFrom(utils,browseURL)
importFrom(utils,install.packages)
importFrom(utils,menu)
importFrom(utils,packageVersion)
importFrom(utils,update.packages)
