% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rfm-shiny-app.R
\name{rfm_launch_app}
\alias{rfm_launch_app}
\title{Launch shiny app}
\usage{
rfm_launch_app()
}
\description{
Launches shiny app.
}
\examples{
\dontrun{
rfm_launch_app()
}
}
